@@ -23,13 +23,34 @@
 namespace usc
 {
 
+struct ActiveOutputs
+{
+    ActiveOutputs(int i, int e) : internal{i}, external{e} {}
+    ActiveOutputs() : ActiveOutputs{0, 0} {}
+
+    bool operator==(ActiveOutputs const& other) const
+    {
+        return internal == other.internal &&
+               external == other.external;
+    }
+
+    int internal;
+    int external;
+};
+
+using ActiveOutputsHandler = std::function<void(ActiveOutputs const&)>;
+
+enum class OutputFilter { all, internal, external };
+
 class Screen
 {
 public:
     virtual ~Screen() = default;
 
-    virtual void turn_on() = 0;
-    virtual void turn_off() = 0;
+    virtual void turn_on(OutputFilter filter) = 0;
+    virtual void turn_off(OutputFilter filter) = 0;
+    virtual void register_active_outputs_handler(
+        ActiveOutputsHandler const& handler) = 0;
 
 protected:
     Screen() = default;
