@@ -108,12 +108,16 @@ public:
     void destroy_buffer(mir::graphics::BufferID) override
     {
     }
+    void send_error(mir::ClientVisibleError const&) override
+    {
+    }
     std::shared_ptr<mir::graphics::Buffer> get_buffer(mir::graphics::BufferID) override
     {
         return nullptr;
     }
     std::string name() const override { return name_; }
     void send_display_config(mir::graphics::DisplayConfiguration const&) override {}
+    void send_input_config(MirInputConfig const&) override {}
 
 private:
     std::string const name_;
